==> kubernetes-model-core-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/PodAntiAffinityFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodAntiAffinityFluent<A extends PodAntiAffinityFluent<A>> extends Fluent<A>{
  public A addToPreferredDuringSchedulingIgnoredDuringExecution(Integer index,WeightedPodAffinityTerm item);
  public A setToPreferredDuringSchedulingIgnoredDuringExecution(Integer index,WeightedPodAffinityTerm item);
  public A addToPreferredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.WeightedPodAffinityTerm... items);
  public A addAllToPreferredDuringSchedulingIgnoredDuringExecution(Collection<WeightedPodAffinityTerm> items);
  public A removeFromPreferredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.WeightedPodAffinityTerm... items);
  public A removeAllFromPreferredDuringSchedulingIgnoredDuringExecution(Collection<WeightedPodAffinityTerm> items);
  public A removeMatchingFromPreferredDuringSchedulingIgnoredDuringExecution(Predicate<WeightedPodAffinityTermBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPreferredDuringSchedulingIgnoredDuringExecution instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<WeightedPodAffinityTerm> getPreferredDuringSchedulingIgnoredDuringExecution();
  public List<WeightedPodAffinityTerm> buildPreferredDuringSchedulingIgnoredDuringExecution();
  public WeightedPodAffinityTerm buildPreferredDuringSchedulingIgnoredDuringExecution(Integer index);
  public WeightedPodAffinityTerm buildFirstPreferredDuringSchedulingIgnoredDuringExecution();
  public WeightedPodAffinityTerm buildLastPreferredDuringSchedulingIgnoredDuringExecution();
  public WeightedPodAffinityTerm buildMatchingPreferredDuringSchedulingIgnoredDuringExecution(Predicate<WeightedPodAffinityTermBuilder> predicate);
  public Boolean hasMatchingPreferredDuringSchedulingIgnoredDuringExecution(Predicate<WeightedPodAffinityTermBuilder> predicate);
  public A withPreferredDuringSchedulingIgnoredDuringExecution(List<WeightedPodAffinityTerm> preferredDuringSchedulingIgnoredDuringExecution);
  public A withPreferredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.WeightedPodAffinityTerm... preferredDuringSchedulingIgnoredDuringExecution);
  public Boolean hasPreferredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecutionLike(WeightedPodAffinityTerm item);
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> setNewPreferredDuringSchedulingIgnoredDuringExecutionLike(Integer index,WeightedPodAffinityTerm item);
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editPreferredDuringSchedulingIgnoredDuringExecution(Integer index);
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstPreferredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editLastPreferredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingPreferredDuringSchedulingIgnoredDuringExecution(Predicate<WeightedPodAffinityTermBuilder> predicate);
  public A addToRequiredDuringSchedulingIgnoredDuringExecution(Integer index,PodAffinityTerm item);
  public A setToRequiredDuringSchedulingIgnoredDuringExecution(Integer index,PodAffinityTerm item);
  public A addToRequiredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.PodAffinityTerm... items);
  public A addAllToRequiredDuringSchedulingIgnoredDuringExecution(Collection<PodAffinityTerm> items);
  public A removeFromRequiredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.PodAffinityTerm... items);
  public A removeAllFromRequiredDuringSchedulingIgnoredDuringExecution(Collection<PodAffinityTerm> items);
  public A removeMatchingFromRequiredDuringSchedulingIgnoredDuringExecution(Predicate<PodAffinityTermBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRequiredDuringSchedulingIgnoredDuringExecution instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodAffinityTerm> getRequiredDuringSchedulingIgnoredDuringExecution();
  public List<PodAffinityTerm> buildRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAffinityTerm buildRequiredDuringSchedulingIgnoredDuringExecution(Integer index);
  public PodAffinityTerm buildFirstRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAffinityTerm buildLastRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAffinityTerm buildMatchingRequiredDuringSchedulingIgnoredDuringExecution(Predicate<PodAffinityTermBuilder> predicate);
  public Boolean hasMatchingRequiredDuringSchedulingIgnoredDuringExecution(Predicate<PodAffinityTermBuilder> predicate);
  public A withRequiredDuringSchedulingIgnoredDuringExecution(List<PodAffinityTerm> requiredDuringSchedulingIgnoredDuringExecution);
  public A withRequiredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.PodAffinityTerm... requiredDuringSchedulingIgnoredDuringExecution);
  public Boolean hasRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> addNewRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> addNewRequiredDuringSchedulingIgnoredDuringExecutionLike(PodAffinityTerm item);
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> setNewRequiredDuringSchedulingIgnoredDuringExecutionLike(Integer index,PodAffinityTerm item);
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editRequiredDuringSchedulingIgnoredDuringExecution(Integer index);
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editLastRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingRequiredDuringSchedulingIgnoredDuringExecution(Predicate<PodAffinityTermBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PreferredDuringSchedulingIgnoredDuringExecutionNested<N> extends Nested<N>,WeightedPodAffinityTermFluent<PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<N>>{
    public N and();
    public N endPreferredDuringSchedulingIgnoredDuringExecution();
    
  }
  public interface RequiredDuringSchedulingIgnoredDuringExecutionNested<N> extends Nested<N>,PodAffinityTermFluent<PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<N>>{
    public N and();
    public N endRequiredDuringSchedulingIgnoredDuringExecution();
    
  }
  
}

==> kubernetes-model-core-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/PodAntiAffinityFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PodAntiAffinityFluent<A extends PodAntiAffinityFluent<A>> extends Fluent<A>{
  public A addToPreferredDuringSchedulingIgnoredDuringExecution(int index,WeightedPodAffinityTerm item);
  public A setToPreferredDuringSchedulingIgnoredDuringExecution(int index,WeightedPodAffinityTerm item);
  public A addToPreferredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.WeightedPodAffinityTerm... items);
  public A addAllToPreferredDuringSchedulingIgnoredDuringExecution(Collection<WeightedPodAffinityTerm> items);
  public A removeFromPreferredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.WeightedPodAffinityTerm... items);
  public A removeAllFromPreferredDuringSchedulingIgnoredDuringExecution(Collection<WeightedPodAffinityTerm> items);
  public A removeMatchingFromPreferredDuringSchedulingIgnoredDuringExecution(Predicate<WeightedPodAffinityTermBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPreferredDuringSchedulingIgnoredDuringExecution instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<WeightedPodAffinityTerm> getPreferredDuringSchedulingIgnoredDuringExecution();
  public List<WeightedPodAffinityTerm> buildPreferredDuringSchedulingIgnoredDuringExecution();
  public WeightedPodAffinityTerm buildPreferredDuringSchedulingIgnoredDuringExecution(int index);
  public WeightedPodAffinityTerm buildFirstPreferredDuringSchedulingIgnoredDuringExecution();
  public WeightedPodAffinityTerm buildLastPreferredDuringSchedulingIgnoredDuringExecution();
  public WeightedPodAffinityTerm buildMatchingPreferredDuringSchedulingIgnoredDuringExecution(Predicate<WeightedPodAffinityTermBuilder> predicate);
  public Boolean hasMatchingPreferredDuringSchedulingIgnoredDuringExecution(Predicate<WeightedPodAffinityTermBuilder> predicate);
  public A withPreferredDuringSchedulingIgnoredDuringExecution(List<WeightedPodAffinityTerm> preferredDuringSchedulingIgnoredDuringExecution);
  public A withPreferredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.WeightedPodAffinityTerm... preferredDuringSchedulingIgnoredDuringExecution);
  public Boolean hasPreferredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecutionLike(WeightedPodAffinityTerm item);
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> setNewPreferredDuringSchedulingIgnoredDuringExecutionLike(int index,WeightedPodAffinityTerm item);
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editPreferredDuringSchedulingIgnoredDuringExecution(int index);
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstPreferredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editLastPreferredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingPreferredDuringSchedulingIgnoredDuringExecution(Predicate<WeightedPodAffinityTermBuilder> predicate);
  public A addToRequiredDuringSchedulingIgnoredDuringExecution(int index,PodAffinityTerm item);
  public A setToRequiredDuringSchedulingIgnoredDuringExecution(int index,PodAffinityTerm item);
  public A addToRequiredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.PodAffinityTerm... items);
  public A addAllToRequiredDuringSchedulingIgnoredDuringExecution(Collection<PodAffinityTerm> items);
  public A removeFromRequiredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.PodAffinityTerm... items);
  public A removeAllFromRequiredDuringSchedulingIgnoredDuringExecution(Collection<PodAffinityTerm> items);
  public A removeMatchingFromRequiredDuringSchedulingIgnoredDuringExecution(Predicate<PodAffinityTermBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRequiredDuringSchedulingIgnoredDuringExecution instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodAffinityTerm> getRequiredDuringSchedulingIgnoredDuringExecution();
  public List<PodAffinityTerm> buildRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAffinityTerm buildRequiredDuringSchedulingIgnoredDuringExecution(int index);
  public PodAffinityTerm buildFirstRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAffinityTerm buildLastRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAffinityTerm buildMatchingRequiredDuringSchedulingIgnoredDuringExecution(Predicate<PodAffinityTermBuilder> predicate);
  public Boolean hasMatchingRequiredDuringSchedulingIgnoredDuringExecution(Predicate<PodAffinityTermBuilder> predicate);
  public A withRequiredDuringSchedulingIgnoredDuringExecution(List<PodAffinityTerm> requiredDuringSchedulingIgnoredDuringExecution);
  public A withRequiredDuringSchedulingIgnoredDuringExecution(io.fabric8.kubernetes.api.model.PodAffinityTerm... requiredDuringSchedulingIgnoredDuringExecution);
  public Boolean hasRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> addNewRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> addNewRequiredDuringSchedulingIgnoredDuringExecutionLike(PodAffinityTerm item);
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> setNewRequiredDuringSchedulingIgnoredDuringExecutionLike(int index,PodAffinityTerm item);
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editRequiredDuringSchedulingIgnoredDuringExecution(int index);
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editLastRequiredDuringSchedulingIgnoredDuringExecution();
  public PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingRequiredDuringSchedulingIgnoredDuringExecution(Predicate<PodAffinityTermBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PreferredDuringSchedulingIgnoredDuringExecutionNested<N> extends Nested<N>,WeightedPodAffinityTermFluent<PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<N>>{
    public N and();
    public N endPreferredDuringSchedulingIgnoredDuringExecution();
    
  }
  public interface RequiredDuringSchedulingIgnoredDuringExecutionNested<N> extends Nested<N>,PodAffinityTermFluent<PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<N>>{
    public N and();
    public N endRequiredDuringSchedulingIgnoredDuringExecution();
    
  }
  
}
